@@ -5,13 +5,14 @@ from PyQt5.QtCore import QTimer, pyqtSlot, pyqtSignal, Qt
 from PyQt5.QtGui import QIcon, QCloseEvent
 from PyQt5.QtWidgets import QDialog, QFileDialog, QMessageBox, QGraphicsTextItem
 
-from urh import constants
+from urh import settings
 from urh.controller.dialogs.ProtocolSniffDialog import ProtocolSniffDialog
 from urh.controller.widgets.DeviceSettingsWidget import DeviceSettingsWidget
 from urh.controller.widgets.ModulationSettingsWidget import ModulationSettingsWidget
 from urh.controller.widgets.SniffSettingsWidget import SniffSettingsWidget
 from urh.dev.BackendHandler import BackendHandler
 from urh.dev.EndlessSender import EndlessSender
+from urh.signalprocessing.IQArray import IQArray
 from urh.simulator.Simulator import Simulator
 from urh.simulator.SimulatorConfiguration import SimulatorConfiguration
 from urh.ui.SimulatorScene import SimulatorScene
@@ -39,6 +40,7 @@ class SimulatorDialog(QDialog):
         self.ui.setupUi(self)
 
         self.setAttribute(Qt.WA_DeleteOnClose)
+        self.setWindowFlags(Qt.Window)
 
         self.simulator_config = simulator_config  # type: SimulatorConfiguration
         self.rx_needed = self.simulator_config.rx_needed
@@ -80,7 +82,7 @@ class SimulatorDialog(QDialog):
 
             sniffer = self.sniff_settings_widget.sniffer
 
-            self.scene_manager = SniffSceneManager(np.array([]), parent=self)
+            self.scene_manager = SniffSceneManager(np.array([], dtype=sniffer.rcv_device.data_type), parent=self)
             self.ui.graphicsViewPreview.setScene(self.scene_manager.scene)
         else:
             self.device_settings_rx_widget = self.sniff_settings_widget = self.scene_manager = None
@@ -128,7 +130,7 @@ class SimulatorDialog(QDialog):
 
         self.ui.textEditTranscript.setFont(util.get_monospace_font())
 
-        if constants.SETTINGS.value('default_view', 0, int) == 1:
+        if settings.read('default_view', 0, int) == 1:
             self.ui.radioButtonTranscriptHex.setChecked(True)
 
     def create_connects(self):
@@ -268,9 +270,9 @@ class SimulatorDialog(QDialog):
         else:
             self.ui.graphicsViewPreview.setEnabled(False)
             if self.ui.checkBoxCaptureFullRX.isChecked():
-                self.scene_manager.plot_data = np.array([])
+                self.scene_manager.plot_data = np.array([], dtype=rx_device.data_type)
             else:
-                self.scene_manager.data_array = np.array([])
+                self.scene_manager.data_array = np.array([], dtype=rx_device.data_type)
             self.scene_manager.scene.addText("Could not generate RX preview.")
 
     @pyqtSlot()
@@ -354,6 +356,7 @@ class SimulatorDialog(QDialog):
         dev_name = self.device_settings_rx_widget.ui.cbDevice.currentText()
         self.simulator.sniffer.device_name = dev_name
         self.device_settings_rx_widget.device = self.simulator.sniffer.rcv_device
+        self.__set_rx_scene()
 
     @pyqtSlot()
     def on_selected_tx_device_changed(self):
@@ -364,7 +367,7 @@ class SimulatorDialog(QDialog):
             self.device_settings_tx_widget.device = self.simulator.sender.device
         except Exception as e:
             self.device_settings_tx_widget.ui.cbDevice.setCurrentText(old_name)
-            Errors.generic_error("Error occurred", str(e))
+            Errors.exception(e)
 
     @pyqtSlot()
     def on_btn_test_sniff_settings_clicked(self):
@@ -391,24 +394,34 @@ class SimulatorDialog(QDialog):
     def on_radio_button_transcript_bit_clicked(self):
         self.update_transcript_view()
 
+    def __set_rx_scene(self):
+        if not self.rx_needed:
+            return
+
+        if self.ui.checkBoxCaptureFullRX.isChecked():
+            self.scene_manager = LiveSceneManager(np.array([], dtype=self.simulator.sniffer.rcv_device.data_type),
+                                                  parent=self)
+            self.ui.graphicsViewPreview.setScene(self.scene_manager.scene)
+        else:
+            self.scene_manager = SniffSceneManager(np.array([], dtype=self.simulator.sniffer.rcv_device.data_type),
+                                                   parent=self)
+
+            self.ui.graphicsViewPreview.setScene(self.scene_manager.scene)
+
     @pyqtSlot()
     def on_checkbox_capture_full_rx_clicked(self):
         self.simulator.sniffer.rcv_device.resume_on_full_receive_buffer = not self.ui.checkBoxCaptureFullRX.isChecked()
-        if self.ui.checkBoxCaptureFullRX.isChecked():
-            self.scene_manager = LiveSceneManager(np.array([]), parent=self)
-            self.ui.graphicsViewPreview.setScene(self.scene_manager.scene)
-        else:
-            self.scene_manager = SniffSceneManager(np.array([]), parent=self)
-
-            self.ui.graphicsViewPreview.setScene(self.scene_manager.scene)
+        self.__set_rx_scene()
 
     @pyqtSlot()
     def on_btn_save_rx_clicked(self):
         rx_device = self.simulator.sniffer.rcv_device
-        if isinstance(rx_device.data, np.ndarray):
-            filename = FileOperator.get_save_file_name("simulation_capture.complex")
+        if isinstance(rx_device.data, np.ndarray) or isinstance(rx_device.data, IQArray):
+            data = IQArray(rx_device.data[:rx_device.current_index])
+            filename = FileOperator.save_data_dialog("simulation_capture", data,
+                                                     sample_rate=rx_device.sample_rate, parent=self)
             if filename:
-                rx_device.data[:rx_device.current_index].tofile(filename)
+                data.tofile(filename)
                 self.rx_file_saved.emit(filename)
 
     @pyqtSlot()
